#
# spec file for package apache2-mod_wsgi
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define modname        mod_wsgi
Name:           apache2-mod_wsgi
Version:        4.4.8
Release:        6.2
Summary:        Python WSGI adapter module for Apache
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
Url:            https://github.com/GrahamDumpleton/mod_wsgi
#Source:        https://github.com/GrahamDumpleton/mod_wsgi/archive/%%{version}.tar.gz
Source:         %{modname}-%{version}.tar.gz
## Work around for inconsistent Apache source tree in SLE 12, see bnc#915479
Patch0:         wsgi_fixVersionCheck.patch
BuildRequires:  python-devel
Provides:       %{modname} = %{version}-%{release}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
%else
%define apache_apxs %{bindir}/apxs
%define apache_sysconfdir %(%{apache_apxs} -q PREFIX)
BuildRequires:  httpd
BuildRequires:  httpd-devel
%endif
%if 0%{?suse_version}
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2
%else
Requires:       httpd
%endif
Conflicts:      apache2-mod_wsgi-python3

%description
The aim of mod_wsgi is to implement a simple to use Apache module which can
host any Python application which supports the Python WSGI interface.

%prep
%setup -q -n %{modname}-%{version}
%patch0 -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
%if 0%{?suse_version}
    --with-apxs="%{apache_apxs}-prefork" \
%else
    --with-apxs="%{apache_apxs}" \
%endif
    --with-python="python"
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} LIBEXECDIR=%{apache_libexecdir}

%post
%if 0%{?suse_version}
if ! %{_sbindir}/a2enmod -q wsgi; then
  %{_sbindir}/a2enmod wsgi
fi
%endif

%postun
%if 0%{?suse_version}
if [ "$1" = "0" ]; then
  if a2enmod -q wsgi; then
    %{_sbindir}/a2enmod -d wsgi
  fi
fi
%endif

%files
%defattr(-,root,root)
%doc LICENSE README.rst docs/release-notes
%dir %{apache_libexecdir}
%{apache_libexecdir}/%{modname}.so

%changelog
* Sat Aug 15 2015 mc@suse.de
- update to 4.4.8
  * Upstream release notes:
    + http://modwsgi.readthedocs.org/en/latest/release-notes/version-4.4.7.html
    + http://modwsgi.readthedocs.org/en/latest/release-notes/version-4.4.8.html
- seperate package for python3 to fix module loading errors
- conflict with mod_wsgi-python3
* Thu Aug  6 2015 mc@suse.com
- Build subpackage with mod_wsgi_python3 (bsc#939717)
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Fri Jan 30 2015 rjschwei@suse.com
- Fix build failure on SLE 12 (Apache 2.4.10)
  + add wsgi_fixVersionCheck.patch
  + build failed due to improper version check
* Fri Jan 30 2015 rjschwei@suse.com
- Update to version 4.4.6
  - Upstream release notes:
    + http://modwsgi.readthedocs.org/en/latest/release-notes/version-4.4.6.html
    + http://modwsgi.readthedocs.org/en/latest/release-notes/version-4.4.5.html
    + http://modwsgi.readthedocs.org/en/latest/release-notes/version-4.4.4.html
    .....
  - As of version 4.2.7 mod_wsgi is effected by
    https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=758035
* Mon Nov  3 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Thu Jul 10 2014 mc@suse.de
- change URL to new location
* Wed Jul  9 2014 mc@suse.de
- provide short module name
* Wed Jul  9 2014 mc@suse.de
- Update to version 4.2.5
  - remove mod_wsgi-3.4-connsbh.patch - included in upstream version
  - remove mod_wsgi-setuid-patch.diff - included in upstream version
  - No longer support the use of mod_python in conjunction with
    mod_wsgi
  - Adding a lot of new configuration option
  - fix off-by-one error in setgroups (bnc#883229)
* Sat May 24 2014 mc@suse.com
- fix Local privilege escalation (bnc#878550)
  CVE-2014-0240
* Mon Apr 28 2014 adaugherity@tamu.edu
- Fix module name sent to a2enmod/a2dismod and fix/cleanup
  post/postun scripts.
* Sat Nov 30 2013 agraf@suse.com
- Add patch "mod_wsgi-3.4-connsbh.patch" to fix segmentation faults
  with apache 2.4 (https://bugzilla.redhat.com/show_bug.cgi?id=831701)
* Wed Jan 30 2013 dimstar@opensuse.org
- Update to version 3.4:
  + New support for Apache 2.4
  + Support for Python 3.2
  + Is now guaranteed that mod_ssl access handler is run before
    that for mod_wsgi so that any per request variables setup by
    mod_ssl are available in the mod_wsgi access handler as
    implemented by WSGIAccessScript directive.
  + Added 'python-home' option to WSGIDaemonProcess.
  + Added 'lang' and 'locale' options to WSGIDaemonProcess.
  + Split combined WWW-Authenticate header returned from daemon
    process back into separate headers.
- Introduce build compatibility with apache 2.4: apxs2 was moved
  from %%{_sbindir} to %%{_bindir}
* Fri Nov 16 2012 saschpe@suse.de
- Require apache2, a module makes little sense without
* Fri Dec 16 2011 chris@computersalat.de
- add post/postun section
  * enable module after install (a2enmod)
  * disable module after deinstall (a2enmod -d)
- fix License as required by http://spdx.org/licenses/
  * Apache-2.0
- fix build for CentOS/RHEL
- spec-cleanup
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Wed Oct 27 2010 termim@gmail.com
- update to 3.3:
  http://code.google.com/p/modwsgi/wiki/ChangesInVersion0303
* Wed May 13 2009 pascal.bleser@opensuse.org
- update to 2.5:
  http://code.google.com/p/modwsgi/wiki/ChangesInVersion0205
- minor spec file fixes (use %%configure, -j%%jobs)
* Wed Sep 17 2008 poeml@suse.de
- update to 2.3. Changelog:
  http://code.google.com/p/modwsgi/wiki/ChangesInVersion0202
  http://code.google.com/p/modwsgi/wiki/ChangesInVersion0203
* Fri Aug  8 2008 poeml@suse.de
- update to 2.1. Changelog:
  http://code.google.com/p/modwsgi/wiki/ChangesInVersion0201
* Tue Mar 11 2008 poeml@suse.de
- initial package (version 1.3)
